boundary.admin.core.ui.inline-editing

Inline (double-click) table-cell editing components.

Pure Hiccup generators for the editable-cell display mode, the inline edit form, and the inline edit form with a validation error.

Inline (double-click) table-cell editing components.

Pure Hiccup generators for the editable-cell display mode, the inline
edit form, and the inline edit form with a validation error.
raw docstring

render-inline-edit-cellclj

(render-inline-edit-cell entity-name record-id field value field-config)

Render an editable table cell (normal display mode).

Args: entity-name: Keyword entity name record-id: Record ID field: Keyword field name value: Current field value field-config: Field configuration map

Returns: Hiccup td element

Render an editable table cell (normal display mode).

Args:
  entity-name: Keyword entity name
  record-id: Record ID
  field: Keyword field name
  value: Current field value
  field-config: Field configuration map

Returns:
  Hiccup td element
sourceraw docstring

render-inline-edit-formclj

(render-inline-edit-form entity-name record-id field value field-config)

Render inline edit form for a single field.

Args: entity-name: Keyword entity name record-id: Record ID field: Keyword field name value: Current field value field-config: Field configuration map

Returns: Hiccup form structure

Render inline edit form for a single field.

Args:
  entity-name: Keyword entity name
  record-id: Record ID
  field: Keyword field name
  value: Current field value
  field-config: Field configuration map

Returns:
  Hiccup form structure
sourceraw docstring

render-inline-edit-form-with-errorclj

(render-inline-edit-form-with-error entity-name
                                    record-id
                                    field
                                    value
                                    field-config
                                    errors)

Render inline edit form with validation error.

Args: entity-name: Keyword entity name record-id: Record ID field: Keyword field name value: Current (invalid) field value field-config: Field configuration map errors: Collection of error messages

Returns: Hiccup form structure with error display

Render inline edit form with validation error.

Args:
  entity-name: Keyword entity name
  record-id: Record ID
  field: Keyword field name
  value: Current (invalid) field value
  field-config: Field configuration map
  errors: Collection of error messages

Returns:
  Hiccup form structure with error display
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries