boundary.admin.shell.http.handlers.crud

Create / update entity handlers.

Create / update entity handlers.
raw docstring

boundary.admin.shell.http.handlers.delete

Delete + bulk-delete entity handlers.

Delete + bulk-delete entity handlers.
raw docstring

boundary.admin.shell.http.handlers.detail

Entity detail / edit page handlers (view existing + new-entity form).

Entity detail / edit page handlers (view existing + new-entity form).
raw docstring

boundary.admin.shell.http.handlers.inline

Inline editing handlers (Week 2): per-field edit widget, update, cancel.

Inline editing handlers (Week 2): per-field edit widget, update, cancel.
raw docstring

boundary.admin.shell.http.handlers.list

Admin home + entity list handlers.

Renders the dashboard, the entity list page, and the HTMX table fragment.

Admin home + entity list handlers.

Renders the dashboard, the entity list page, and the HTMX table fragment.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries