boundary.admin.shell.http.handlers.crud

Create / update entity handlers.

Create / update entity handlers.
raw docstring

create-entity-handlerclj

(create-entity-handler admin-service schema-provider config)

Handler for creating new entity.

Validates form data, creates entity, redirects to list with flash message.

Handler for creating new entity.

Validates form data, creates entity, redirects to list with flash message.
sourceraw docstring

update-entity-handlerclj

(update-entity-handler admin-service schema-provider config)

Handler for updating existing entity.

Validates form data, updates entity, redirects to list with flash message.

Handler for updating existing entity.

Validates form data, updates entity, redirects to list with flash message.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries