Create / update entity handlers.
Create / update entity handlers.
Delete + bulk-delete entity handlers.
Delete + bulk-delete entity handlers.
Entity detail / edit page handlers (view existing + new-entity form).
Entity detail / edit page handlers (view existing + new-entity form).
Inline editing handlers (Week 2): per-field edit widget, update, cancel.
Inline editing handlers (Week 2): per-field edit widget, update, cancel.
Admin home + entity list handlers.
Renders the dashboard, the entity list page, and the HTMX table fragment.
Admin home + entity list handlers. Renders the dashboard, the entity list page, and the HTMX table fragment.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |