Create / update entity handlers.
Create / update entity handlers.
(create-entity-handler admin-service schema-provider config)Handler for creating new entity.
Validates form data, creates entity, redirects to list with flash message.
Handler for creating new entity. Validates form data, creates entity, redirects to list with flash message.
(update-entity-handler admin-service schema-provider config)Handler for updating existing entity.
Validates form data, updates entity, redirects to list with flash message.
Handler for updating existing entity. Validates form data, updates entity, redirects to list with flash message.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |